@@ -23,14 +23,25 @@
 #include "importproject.h"
 #include "library.h"
 #include "newsuppressiondialog.h"
+#include "platform.h"
 #include "platforms.h"
 #include "projectfile.h"
+#include "settings.h"
+
+#include "ui_projectfile.h"
+
+#include <list>
+#include <string>
 
 #include <QDir>
 #include <QFileDialog>
 #include <QFileInfo>
+#include <QRegularExpression>
+#include <QRegularExpressionValidator>
 #include <QSettings>
 
+class QModelIndex;
+
 /** Return paths from QListWidget */
 static QStringList getPaths(const QListWidget *list)
 {
@@ -70,11 +81,12 @@ QStringList ProjectFileDialog::getProjectConfigs(const QString &fileName)
 
 ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
     : QDialog(parent)
+    , mUI(new Ui::ProjectFile)
     , mProjectFile(projectFile)
 {
-    mUI.setupUi(this);
+    mUI->setupUi(this);
 
-    mUI.mToolClangAnalyzer->hide();
+    mUI->mToolClangAnalyzer->hide();
 
     const QFileInfo inf(projectFile->getFilename());
     QString filename = inf.fileName();
@@ -97,12 +109,12 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
     QStringList libs;
     // Search the std.cfg first since other libraries could depend on it
     QString stdLibraryFilename;
-    foreach (const QString sp, searchPaths) {
+    for (const QString &sp : searchPaths) {
         QDir dir(sp);
         dir.setSorting(QDir::Name);
         dir.setNameFilters(QStringList("*.cfg"));
         dir.setFilter(QDir::Files | QDir::NoDotAndDotDot);
-        foreach (QFileInfo item, dir.entryInfoList()) {
+        for (const QFileInfo& item : dir.entryInfoList()) {
             QString library = item.fileName();
             if (library.compare("std.cfg", Qt::CaseInsensitive) != 0)
                 continue;
@@ -119,12 +131,12 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
             break;
     }
     // Search other libraries
-    foreach (const QString sp, searchPaths) {
+    for (const QString &sp : searchPaths) {
         QDir dir(sp);
         dir.setSorting(QDir::Name);
         dir.setNameFilters(QStringList("*.cfg"));
         dir.setFilter(QDir::Files | QDir::NoDotAndDotDot);
-        foreach (QFileInfo item, dir.entryInfoList()) {
+        for (const QFileInfo& item : dir.entryInfoList()) {
             QString library = item.fileName();
             {
                 Library lib;
@@ -146,9 +158,9 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
         }
     }
     libs.sort();
-    mUI.mLibraries->clear();
+    mUI->mLibraries->clear();
     for (const QString &lib : libs) {
-        QListWidgetItem* item = new QListWidgetItem(lib, mUI.mLibraries);
+        QListWidgetItem* item = new QListWidgetItem(lib, mUI->mLibraries);
         item->setFlags(item->flags() | Qt::ItemIsUserCheckable); // set checkable flag
         item->setCheckState(Qt::Unchecked); // AND initialize check state
     }
@@ -156,16 +168,16 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
     // Platforms..
     Platforms platforms;
     for (cppcheck::Platform::PlatformType builtinPlatform : builtinPlatforms)
-        mUI.mComboBoxPlatform->addItem(platforms.get(builtinPlatform).mTitle);
+        mUI->mComboBoxPlatform->addItem(platforms.get(builtinPlatform).mTitle);
     QStringList platformFiles;
-    foreach (QString sp, searchPaths) {
+    for (QString sp : searchPaths) {
         if (sp.endsWith("/cfg"))
             sp = sp.mid(0,sp.length()-3) + "platforms";
         QDir dir(sp);
         dir.setSorting(QDir::Name);
         dir.setNameFilters(QStringList("*.xml"));
         dir.setFilter(QDir::Files | QDir::NoDotAndDotDot);
-        foreach (QFileInfo item, dir.entryInfoList()) {
+        for (const QFileInfo& item : dir.entryInfoList()) {
             const QString platformFile = item.fileName();
 
             cppcheck::Platform plat2;
@@ -177,41 +189,41 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
         }
     }
     platformFiles.sort();
-    mUI.mComboBoxPlatform->addItems(platformFiles);
+    mUI->mComboBoxPlatform->addItems(platformFiles);
 
-    mUI.mEditTags->setValidator(new QRegExpValidator(QRegExp("[a-zA-Z0-9 ;]*"),this));
+    mUI->mEditTags->setValidator(new QRegularExpressionValidator(QRegularExpression("[a-zA-Z0-9 ;]*"),this));
 
-    const QRegExp undefRegExp("\\s*([a-zA-Z_][a-zA-Z0-9_]*[; ]*)*");
-    mUI.mEditUndefines->setValidator(new QRegExpValidator(undefRegExp, this));
+    const QRegularExpression undefRegExp("\\s*([a-zA-Z_][a-zA-Z0-9_]*[; ]*)*");
+    mUI->mEditUndefines->setValidator(new QRegularExpressionValidator(undefRegExp, this));
 
-    connect(mUI.mButtons, &QDialogButtonBox::accepted, this, &ProjectFileDialog::ok);
-    connect(mUI.mBtnBrowseBuildDir, &QPushButton::clicked, this, &ProjectFileDialog::browseBuildDir);
-    connect(mUI.mBtnClearImportProject, &QPushButton::clicked, this, &ProjectFileDialog::clearImportProject);
-    connect(mUI.mBtnBrowseImportProject, &QPushButton::clicked, this, &ProjectFileDialog::browseImportProject);
-    connect(mUI.mBtnAddCheckPath, SIGNAL(clicked()), this, SLOT(addCheckPath()));
-    connect(mUI.mBtnEditCheckPath, &QPushButton::clicked, this, &ProjectFileDialog::editCheckPath);
-    connect(mUI.mBtnRemoveCheckPath, &QPushButton::clicked, this, &ProjectFileDialog::removeCheckPath);
-    connect(mUI.mBtnAddInclude, SIGNAL(clicked()), this, SLOT(addIncludeDir()));
-    connect(mUI.mBtnEditInclude, &QPushButton::clicked, this, &ProjectFileDialog::editIncludeDir);
-    connect(mUI.mBtnRemoveInclude, &QPushButton::clicked, this, &ProjectFileDialog::removeIncludeDir);
-    connect(mUI.mBtnAddIgnorePath, SIGNAL(clicked()), this, SLOT(addExcludePath()));
-    connect(mUI.mBtnAddIgnoreFile, SIGNAL(clicked()), this, SLOT(addExcludeFile()));
-    connect(mUI.mBtnEditIgnorePath, &QPushButton::clicked, this, &ProjectFileDialog::editExcludePath);
-    connect(mUI.mBtnRemoveIgnorePath, &QPushButton::clicked, this, &ProjectFileDialog::removeExcludePath);
-    connect(mUI.mBtnIncludeUp, &QPushButton::clicked, this, &ProjectFileDialog::moveIncludePathUp);
-    connect(mUI.mBtnIncludeDown, &QPushButton::clicked, this, &ProjectFileDialog::moveIncludePathDown);
-    connect(mUI.mBtnAddSuppression, &QPushButton::clicked, this, &ProjectFileDialog::addSuppression);
-    connect(mUI.mBtnRemoveSuppression, &QPushButton::clicked, this, &ProjectFileDialog::removeSuppression);
-    connect(mUI.mListSuppressions, &QListWidget::doubleClicked, this, &ProjectFileDialog::editSuppression);
-    connect(mUI.mBtnBrowseMisraFile, &QPushButton::clicked, this, &ProjectFileDialog::browseMisraFile);
-    connect(mUI.mChkAllVsConfigs, &QCheckBox::clicked, this, &ProjectFileDialog::checkAllVSConfigs);
-    connect(mUI.mBtnNormalAnalysis, &QCheckBox::toggled, mUI.mBtnSafeClasses, &QCheckBox::setEnabled);
+    connect(mUI->mButtons, &QDialogButtonBox::accepted, this, &ProjectFileDialog::ok);
+    connect(mUI->mBtnBrowseBuildDir, &QPushButton::clicked, this, &ProjectFileDialog::browseBuildDir);
+    connect(mUI->mBtnClearImportProject, &QPushButton::clicked, this, &ProjectFileDialog::clearImportProject);
+    connect(mUI->mBtnBrowseImportProject, &QPushButton::clicked, this, &ProjectFileDialog::browseImportProject);
+    connect(mUI->mBtnAddCheckPath, SIGNAL(clicked()), this, SLOT(addCheckPath()));
+    connect(mUI->mBtnEditCheckPath, &QPushButton::clicked, this, &ProjectFileDialog::editCheckPath);
+    connect(mUI->mBtnRemoveCheckPath, &QPushButton::clicked, this, &ProjectFileDialog::removeCheckPath);
+    connect(mUI->mBtnAddInclude, SIGNAL(clicked()), this, SLOT(addIncludeDir()));
+    connect(mUI->mBtnEditInclude, &QPushButton::clicked, this, &ProjectFileDialog::editIncludeDir);
+    connect(mUI->mBtnRemoveInclude, &QPushButton::clicked, this, &ProjectFileDialog::removeIncludeDir);
+    connect(mUI->mBtnAddIgnorePath, SIGNAL(clicked()), this, SLOT(addExcludePath()));
+    connect(mUI->mBtnAddIgnoreFile, SIGNAL(clicked()), this, SLOT(addExcludeFile()));
+    connect(mUI->mBtnEditIgnorePath, &QPushButton::clicked, this, &ProjectFileDialog::editExcludePath);
+    connect(mUI->mBtnRemoveIgnorePath, &QPushButton::clicked, this, &ProjectFileDialog::removeExcludePath);
+    connect(mUI->mBtnIncludeUp, &QPushButton::clicked, this, &ProjectFileDialog::moveIncludePathUp);
+    connect(mUI->mBtnIncludeDown, &QPushButton::clicked, this, &ProjectFileDialog::moveIncludePathDown);
+    connect(mUI->mBtnAddSuppression, &QPushButton::clicked, this, &ProjectFileDialog::addSuppression);
+    connect(mUI->mBtnRemoveSuppression, &QPushButton::clicked, this, &ProjectFileDialog::removeSuppression);
+    connect(mUI->mListSuppressions, &QListWidget::doubleClicked, this, &ProjectFileDialog::editSuppression);
+    connect(mUI->mBtnBrowseMisraFile, &QPushButton::clicked, this, &ProjectFileDialog::browseMisraFile);
+    connect(mUI->mChkAllVsConfigs, &QCheckBox::clicked, this, &ProjectFileDialog::checkAllVSConfigs);
     loadFromProjectFile(projectFile);
 }
 
 ProjectFileDialog::~ProjectFileDialog()
 {
     saveSettings();
+    delete mUI;
 }
 
 void ProjectFileDialog::loadSettings()
@@ -240,13 +252,13 @@ static void updateAddonCheckBox(QCheckBox *cb, const ProjectFile *projectFile, c
 
 void ProjectFileDialog::checkAllVSConfigs()
 {
-    if (mUI.mChkAllVsConfigs->isChecked()) {
-        for (int row = 0; row < mUI.mListVsConfigs->count(); ++row) {
-            QListWidgetItem *item = mUI.mListVsConfigs->item(row);
+    if (mUI->mChkAllVsConfigs->isChecked()) {
+        for (int row = 0; row < mUI->mListVsConfigs->count(); ++row) {
+            QListWidgetItem *item = mUI->mListVsConfigs->item(row);
             item->setCheckState(Qt::Checked);
         }
     }
-    mUI.mListVsConfigs->setEnabled(!mUI.mChkAllVsConfigs->isChecked());
+    mUI->mListVsConfigs->setEnabled(!mUI->mChkAllVsConfigs->isChecked());
 }
 
 void ProjectFileDialog::loadFromProjectFile(const ProjectFile *projectFile)
@@ -258,39 +270,38 @@ void ProjectFileDialog::loadFromProjectFile(const ProjectFile *projectFile)
     setUndefines(projectFile->getUndefines());
     setCheckPaths(projectFile->getCheckPaths());
     setImportProject(projectFile->getImportProject());
-    mUI.mChkAllVsConfigs->setChecked(projectFile->getAnalyzeAllVsConfigs());
-    setProjectConfigurations(getProjectConfigs(mUI.mEditImportProject->text()));
-    for (int row = 0; row < mUI.mListVsConfigs->count(); ++row) {
-        QListWidgetItem *item = mUI.mListVsConfigs->item(row);
+    mUI->mChkAllVsConfigs->setChecked(projectFile->getAnalyzeAllVsConfigs());
+    setProjectConfigurations(getProjectConfigs(mUI->mEditImportProject->text()));
+    for (int row = 0; row < mUI->mListVsConfigs->count(); ++row) {
+        QListWidgetItem *item = mUI->mListVsConfigs->item(row);
         if (projectFile->getAnalyzeAllVsConfigs() || projectFile->getVsConfigurations().contains(item->text()))
             item->setCheckState(Qt::Checked);
         else
             item->setCheckState(Qt::Unchecked);
     }
-    mUI.mCheckHeaders->setChecked(projectFile->getCheckHeaders());
-    mUI.mCheckUnusedTemplates->setChecked(projectFile->getCheckUnusedTemplates());
-    mUI.mMaxCtuDepth->setValue(projectFile->getMaxCtuDepth());
-    mUI.mMaxTemplateRecursion->setValue(projectFile->getMaxTemplateRecursion());
+    mUI->mCheckHeaders->setChecked(projectFile->getCheckHeaders());
+    mUI->mCheckUnusedTemplates->setChecked(projectFile->getCheckUnusedTemplates());
+    mUI->mMaxCtuDepth->setValue(projectFile->getMaxCtuDepth());
+    mUI->mMaxTemplateRecursion->setValue(projectFile->getMaxTemplateRecursion());
     if (projectFile->clangParser)
-        mUI.mBtnClangParser->setChecked(true);
+        mUI->mBtnClangParser->setChecked(true);
     else
-        mUI.mBtnCppcheckParser->setChecked(true);
-    mUI.mBtnSafeClasses->setChecked(projectFile->safeChecks.classes);
-    mUI.mBtnBugHunting->setChecked(projectFile->bugHunting);
+        mUI->mBtnCppcheckParser->setChecked(true);
+    mUI->mBtnSafeClasses->setChecked(projectFile->safeChecks.classes);
     setExcludedPaths(projectFile->getExcludedPaths());
     setLibraries(projectFile->getLibraries());
     const QString platform = projectFile->getPlatform();
     if (platform.endsWith(".xml")) {
         int i;
-        for (i = numberOfBuiltinPlatforms; i < mUI.mComboBoxPlatform->count(); ++i) {
-            if (mUI.mComboBoxPlatform->itemText(i) == platform)
+        for (i = numberOfBuiltinPlatforms; i < mUI->mComboBoxPlatform->count(); ++i) {
+            if (mUI->mComboBoxPlatform->itemText(i) == platform)
                 break;
         }
-        if (i < mUI.mComboBoxPlatform->count())
-            mUI.mComboBoxPlatform->setCurrentIndex(i);
+        if (i < mUI->mComboBoxPlatform->count())
+            mUI->mComboBoxPlatform->setCurrentIndex(i);
         else {
-            mUI.mComboBoxPlatform->addItem(platform);
-            mUI.mComboBoxPlatform->setCurrentIndex(i);
+            mUI->mComboBoxPlatform->addItem(platform);
+            mUI->mComboBoxPlatform->setCurrentIndex(i);
         }
     } else {
         int i;
@@ -300,52 +311,51 @@ void ProjectFileDialog::loadFromProjectFile(const ProjectFile *projectFile)
                 break;
         }
         if (i < numberOfBuiltinPlatforms)
-            mUI.mComboBoxPlatform->setCurrentIndex(i);
+            mUI->mComboBoxPlatform->setCurrentIndex(i);
         else
-            mUI.mComboBoxPlatform->setCurrentIndex(-1);
+            mUI->mComboBoxPlatform->setCurrentIndex(-1);
     }
 
-    mUI.mComboBoxPlatform->setCurrentText(projectFile->getPlatform());
+    mUI->mComboBoxPlatform->setCurrentText(projectFile->getPlatform());
     setSuppressions(projectFile->getSuppressions());
 
     // Human knowledge..
     /*
-       mUI.mListUnknownFunctionReturn->clear();
-       mUI.mListUnknownFunctionReturn->addItem("rand()");
-       for (int row = 0; row < mUI.mListUnknownFunctionReturn->count(); ++row) {
-        QListWidgetItem *item = mUI.mListUnknownFunctionReturn->item(row);
+       mUI->mListUnknownFunctionReturn->clear();
+       mUI->mListUnknownFunctionReturn->addItem("rand()");
+       for (int row = 0; row < mUI->mListUnknownFunctionReturn->count(); ++row) {
+        QListWidgetItem *item = mUI->mListUnknownFunctionReturn->item(row);
         item->setFlags(item->flags() | Qt::ItemIsUserCheckable); // set checkable flag
         const bool unknownValues = projectFile->getCheckUnknownFunctionReturn().contains(item->text());
         item->setCheckState(unknownValues ? Qt::Checked : Qt::Unchecked); // AND initialize check state
        }
-       mUI.mCheckSafeClasses->setChecked(projectFile->getSafeChecks().classes);
-       mUI.mCheckSafeExternalFunctions->setChecked(projectFile->getSafeChecks().externalFunctions);
-       mUI.mCheckSafeInternalFunctions->setChecked(projectFile->getSafeChecks().internalFunctions);
-       mUI.mCheckSafeExternalVariables->setChecked(projectFile->getSafeChecks().externalVariables);
+       mUI->mCheckSafeClasses->setChecked(projectFile->getSafeChecks().classes);
+       mUI->mCheckSafeExternalFunctions->setChecked(projectFile->getSafeChecks().externalFunctions);
+       mUI->mCheckSafeInternalFunctions->setChecked(projectFile->getSafeChecks().internalFunctions);
+       mUI->mCheckSafeExternalVariables->setChecked(projectFile->getSafeChecks().externalVariables);
      */
 
     // Addons..
     QSettings settings;
     const QString dataDir = getDataDir();
-    updateAddonCheckBox(mUI.mAddonThreadSafety, projectFile, dataDir, "threadsafety");
-    updateAddonCheckBox(mUI.mAddonY2038, projectFile, dataDir, "y2038");
-    updateAddonCheckBox(mUI.mAddonCert, projectFile, dataDir, "cert");
-    updateAddonCheckBox(mUI.mAddonMisra, projectFile, dataDir, "misra");
+    updateAddonCheckBox(mUI->mAddonThreadSafety, projectFile, dataDir, "threadsafety");
+    updateAddonCheckBox(mUI->mAddonY2038, projectFile, dataDir, "y2038");
+    updateAddonCheckBox(mUI->mAddonMisra, projectFile, dataDir, "misra");
 
     const QString &misraFile = settings.value(SETTINGS_MISRA_FILE, QString()).toString();
-    mUI.mEditMisraFile->setText(misraFile);
-    if (!mUI.mAddonMisra->isEnabled()) {
-        mUI.mEditMisraFile->setEnabled(false);
-        mUI.mBtnBrowseMisraFile->setEnabled(false);
+    mUI->mEditMisraFile->setText(misraFile);
+    if (!mUI->mAddonMisra->isEnabled()) {
+        mUI->mEditMisraFile->setEnabled(false);
+        mUI->mBtnBrowseMisraFile->setEnabled(false);
     }
 
-    mUI.mToolClangAnalyzer->setChecked(projectFile->getClangAnalyzer());
-    mUI.mToolClangTidy->setChecked(projectFile->getClangTidy());
+    mUI->mToolClangAnalyzer->setChecked(projectFile->getClangAnalyzer());
+    mUI->mToolClangTidy->setChecked(projectFile->getClangTidy());
     if (CheckThread::clangTidyCmd().isEmpty()) {
-        mUI.mToolClangTidy->setText(tr("Clang-tidy (not found)"));
-        mUI.mToolClangTidy->setEnabled(false);
+        mUI->mToolClangTidy->setText(tr("Clang-tidy (not found)"));
+        mUI->mToolClangTidy->setEnabled(false);
     }
-    mUI.mEditTags->setText(projectFile->getTags().join(';'));
+    mUI->mEditTags->setText(projectFile->getTags().join(';'));
     updatePathsAndDefines();
 }
 
@@ -354,25 +364,24 @@ void ProjectFileDialog::saveToProjectFile(ProjectFile *projectFile) const
     projectFile->setRootPath(getRootPath());
     projectFile->setBuildDir(getBuildDir());
     projectFile->setImportProject(getImportProject());
-    projectFile->setAnalyzeAllVsConfigs(mUI.mChkAllVsConfigs->isChecked());
+    projectFile->setAnalyzeAllVsConfigs(mUI->mChkAllVsConfigs->isChecked());
     projectFile->setVSConfigurations(getProjectConfigurations());
-    projectFile->setCheckHeaders(mUI.mCheckHeaders->isChecked());
-    projectFile->setCheckUnusedTemplates(mUI.mCheckUnusedTemplates->isChecked());
-    projectFile->setMaxCtuDepth(mUI.mMaxCtuDepth->value());
-    projectFile->setMaxTemplateRecursion(mUI.mMaxTemplateRecursion->value());
+    projectFile->setCheckHeaders(mUI->mCheckHeaders->isChecked());
+    projectFile->setCheckUnusedTemplates(mUI->mCheckUnusedTemplates->isChecked());
+    projectFile->setMaxCtuDepth(mUI->mMaxCtuDepth->value());
+    projectFile->setMaxTemplateRecursion(mUI->mMaxTemplateRecursion->value());
     projectFile->setIncludes(getIncludePaths());
     projectFile->setDefines(getDefines());
     projectFile->setUndefines(getUndefines());
     projectFile->setCheckPaths(getCheckPaths());
     projectFile->setExcludedPaths(getExcludedPaths());
     projectFile->setLibraries(getLibraries());
-    projectFile->clangParser = mUI.mBtnClangParser->isChecked();
-    projectFile->safeChecks.classes = mUI.mBtnSafeClasses->isChecked();
-    projectFile->bugHunting = mUI.mBtnBugHunting->isChecked();
-    if (mUI.mComboBoxPlatform->currentText().endsWith(".xml"))
-        projectFile->setPlatform(mUI.mComboBoxPlatform->currentText());
+    projectFile->clangParser = mUI->mBtnClangParser->isChecked();
+    projectFile->safeChecks.classes = mUI->mBtnSafeClasses->isChecked();
+    if (mUI->mComboBoxPlatform->currentText().endsWith(".xml"))
+        projectFile->setPlatform(mUI->mComboBoxPlatform->currentText());
     else {
-        int i = mUI.mComboBoxPlatform->currentIndex();
+        int i = mUI->mComboBoxPlatform->currentIndex();
         if (i < numberOfBuiltinPlatforms)
             projectFile->setPlatform(cppcheck::Platform::platformString(builtinPlatforms[i]));
         else
@@ -382,36 +391,34 @@ void ProjectFileDialog::saveToProjectFile(ProjectFile *projectFile) const
     // Human knowledge
     /*
        QStringList unknownReturnValues;
-       for (int row = 0; row < mUI.mListUnknownFunctionReturn->count(); ++row) {
-        QListWidgetItem *item = mUI.mListUnknownFunctionReturn->item(row);
+       for (int row = 0; row < mUI->mListUnknownFunctionReturn->count(); ++row) {
+        QListWidgetItem *item = mUI->mListUnknownFunctionReturn->item(row);
         if (item->checkState() == Qt::Checked)
             unknownReturnValues << item->text();
        }
        projectFile->setCheckUnknownFunctionReturn(unknownReturnValues);
        ProjectFile::SafeChecks safeChecks;
-       safeChecks.classes = mUI.mCheckSafeClasses->isChecked();
-       safeChecks.externalFunctions = mUI.mCheckSafeExternalFunctions->isChecked();
-       safeChecks.internalFunctions = mUI.mCheckSafeInternalFunctions->isChecked();
-       safeChecks.externalVariables = mUI.mCheckSafeExternalVariables->isChecked();
+       safeChecks.classes = mUI->mCheckSafeClasses->isChecked();
+       safeChecks.externalFunctions = mUI->mCheckSafeExternalFunctions->isChecked();
+       safeChecks.internalFunctions = mUI->mCheckSafeInternalFunctions->isChecked();
+       safeChecks.externalVariables = mUI->mCheckSafeExternalVariables->isChecked();
        projectFile->setSafeChecks(safeChecks);
      */
     // Addons
     QStringList list;
-    if (mUI.mAddonThreadSafety->isChecked())
+    if (mUI->mAddonThreadSafety->isChecked())
         list << "threadsafety";
-    if (mUI.mAddonY2038->isChecked())
+    if (mUI->mAddonY2038->isChecked())
         list << "y2038";
-    if (mUI.mAddonCert->isChecked())
-        list << "cert";
-    if (mUI.mAddonMisra->isChecked())
+    if (mUI->mAddonMisra->isChecked())
         list << "misra";
     projectFile->setAddons(list);
-    projectFile->setClangAnalyzer(mUI.mToolClangAnalyzer->isChecked());
-    projectFile->setClangTidy(mUI.mToolClangTidy->isChecked());
+    projectFile->setClangAnalyzer(mUI->mToolClangAnalyzer->isChecked());
+    projectFile->setClangTidy(mUI->mToolClangTidy->isChecked());
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-    projectFile->setTags(mUI.mEditTags->text().split(";", Qt::SkipEmptyParts));
+    projectFile->setTags(mUI->mEditTags->text().split(";", Qt::SkipEmptyParts));
 #else
-    projectFile->setTags(mUI.mEditTags->text().split(";", QString::SkipEmptyParts));
+    projectFile->setTags(mUI->mEditTags->text().split(";", QString::SkipEmptyParts));
 #endif
 }
 
@@ -451,36 +458,36 @@ void ProjectFileDialog::browseBuildDir()
 {
     const QString dir(getExistingDirectory(tr("Select Cppcheck build dir"), false));
     if (!dir.isEmpty())
-        mUI.mEditBuildDir->setText(dir);
+        mUI->mEditBuildDir->setText(dir);
 }
 
 void ProjectFileDialog::updatePathsAndDefines()
 {
-    const QString &fileName = mUI.mEditImportProject->text();
+    const QString &fileName = mUI->mEditImportProject->text();
     bool importProject = !fileName.isEmpty();
     bool hasConfigs = fileName.endsWith(".sln") || fileName.endsWith(".vcxproj");
-    mUI.mBtnClearImportProject->setEnabled(importProject);
-    mUI.mListCheckPaths->setEnabled(!importProject);
-    mUI.mListIncludeDirs->setEnabled(!importProject);
-    mUI.mBtnAddCheckPath->setEnabled(!importProject);
-    mUI.mBtnEditCheckPath->setEnabled(!importProject);
-    mUI.mBtnRemoveCheckPath->setEnabled(!importProject);
-    mUI.mEditDefines->setEnabled(!importProject);
-    mUI.mEditUndefines->setEnabled(!importProject);
-    mUI.mBtnAddInclude->setEnabled(!importProject);
-    mUI.mBtnEditInclude->setEnabled(!importProject);
-    mUI.mBtnRemoveInclude->setEnabled(!importProject);
-    mUI.mBtnIncludeUp->setEnabled(!importProject);
-    mUI.mBtnIncludeDown->setEnabled(!importProject);
-    mUI.mChkAllVsConfigs->setEnabled(hasConfigs);
-    mUI.mListVsConfigs->setEnabled(hasConfigs && !mUI.mChkAllVsConfigs->isChecked());
+    mUI->mBtnClearImportProject->setEnabled(importProject);
+    mUI->mListCheckPaths->setEnabled(!importProject);
+    mUI->mListIncludeDirs->setEnabled(!importProject);
+    mUI->mBtnAddCheckPath->setEnabled(!importProject);
+    mUI->mBtnEditCheckPath->setEnabled(!importProject);
+    mUI->mBtnRemoveCheckPath->setEnabled(!importProject);
+    mUI->mEditDefines->setEnabled(!importProject);
+    mUI->mEditUndefines->setEnabled(!importProject);
+    mUI->mBtnAddInclude->setEnabled(!importProject);
+    mUI->mBtnEditInclude->setEnabled(!importProject);
+    mUI->mBtnRemoveInclude->setEnabled(!importProject);
+    mUI->mBtnIncludeUp->setEnabled(!importProject);
+    mUI->mBtnIncludeDown->setEnabled(!importProject);
+    mUI->mChkAllVsConfigs->setEnabled(hasConfigs);
+    mUI->mListVsConfigs->setEnabled(hasConfigs && !mUI->mChkAllVsConfigs->isChecked());
     if (!hasConfigs)
-        mUI.mListVsConfigs->clear();
+        mUI->mListVsConfigs->clear();
 }
 
 void ProjectFileDialog::clearImportProject()
 {
-    mUI.mEditImportProject->clear();
+    mUI->mEditImportProject->clear();
     updatePathsAndDefines();
 }
 
@@ -496,11 +503,11 @@ void ProjectFileDialog::browseImportProject()
                                                     dir.canonicalPath(),
                                                     toFilterString(filters));
     if (!fileName.isEmpty()) {
-        mUI.mEditImportProject->setText(dir.relativeFilePath(fileName));
+        mUI->mEditImportProject->setText(dir.relativeFilePath(fileName));
         updatePathsAndDefines();
         setProjectConfigurations(getProjectConfigs(fileName));
-        for (int row = 0; row < mUI.mListVsConfigs->count(); ++row) {
-            QListWidgetItem *item = mUI.mListVsConfigs->item(row);
+        for (int row = 0; row < mUI->mListVsConfigs->count(); ++row) {
+            QListWidgetItem *item = mUI->mListVsConfigs->item(row);
             item->setCheckState(Qt::Checked);
         }
     }
@@ -509,8 +516,8 @@ void ProjectFileDialog::browseImportProject()
 QStringList ProjectFileDialog::getProjectConfigurations() const
 {
     QStringList configs;
-    for (int row = 0; row < mUI.mListVsConfigs->count(); ++row) {
-        QListWidgetItem *item = mUI.mListVsConfigs->item(row);
+    for (int row = 0; row < mUI->mListVsConfigs->count(); ++row) {
+        QListWidgetItem *item = mUI->mListVsConfigs->item(row);
         if (item->checkState() == Qt::Checked)
             configs << item->text();
     }
@@ -519,10 +526,10 @@ QStringList ProjectFileDialog::getProjectConfigurations() const
 
 void ProjectFileDialog::setProjectConfigurations(const QStringList &configs)
 {
-    mUI.mListVsConfigs->clear();
-    mUI.mListVsConfigs->setEnabled(!configs.isEmpty() && !mUI.mChkAllVsConfigs->isChecked());
-    foreach (const QString &cfg, configs) {
-        QListWidgetItem* item = new QListWidgetItem(cfg, mUI.mListVsConfigs);
+    mUI->mListVsConfigs->clear();
+    mUI->mListVsConfigs->setEnabled(!configs.isEmpty() && !mUI->mChkAllVsConfigs->isChecked());
+    for (const QString &cfg : configs) {
+        QListWidgetItem* item = new QListWidgetItem(cfg, mUI->mListVsConfigs);
         item->setFlags(item->flags() | Qt::ItemIsUserCheckable); // set checkable flag
         item->setCheckState(Qt::Unchecked);
     }
@@ -530,7 +537,7 @@ void ProjectFileDialog::setProjectConfigurations(const QStringList &configs)
 
 QString ProjectFileDialog::getImportProject() const
 {
-    return mUI.mEditImportProject->text();
+    return mUI->mEditImportProject->text();
 }
 
 void ProjectFileDialog::addIncludeDir(const QString &dir)
@@ -541,7 +548,7 @@ void ProjectFileDialog::addIncludeDir(const QString &dir)
     const QString newdir = QDir::toNativeSeparators(dir);
     QListWidgetItem *item = new QListWidgetItem(newdir);
     item->setFlags(item->flags() | Qt::ItemIsEditable);
-    mUI.mListIncludeDirs->addItem(item);
+    mUI->mListIncludeDirs->addItem(item);
 }
 
 void ProjectFileDialog::addCheckPath(const QString &path)
@@ -552,7 +559,7 @@ void ProjectFileDialog::addCheckPath(const QString &path)
     const QString newpath = QDir::toNativeSeparators(path);
     QListWidgetItem *item = new QListWidgetItem(newpath);
     item->setFlags(item->flags() | Qt::ItemIsEditable);
-    mUI.mListCheckPaths->addItem(item);
+    mUI->mListCheckPaths->addItem(item);
 }
 
 void ProjectFileDialog::addExcludePath(const QString &path)
@@ -563,12 +570,12 @@ void ProjectFileDialog::addExcludePath(const QString &path)
     const QString newpath = QDir::toNativeSeparators(path);
     QListWidgetItem *item = new QListWidgetItem(newpath);
     item->setFlags(item->flags() | Qt::ItemIsEditable);
-    mUI.mListExcludedPaths->addItem(item);
+    mUI->mListExcludedPaths->addItem(item);
 }
 
 QString ProjectFileDialog::getRootPath() const
 {
-    QString root = mUI.mEditProjectRoot->text();
+    QString root = mUI->mEditProjectRoot->text();
     root = root.trimmed();
     root = QDir::fromNativeSeparators(root);
     return root;
@@ -576,30 +583,30 @@ QString ProjectFileDialog::getRootPath() const
 
 QString ProjectFileDialog::getBuildDir() const
 {
-    return mUI.mEditBuildDir->text();
+    return mUI->mEditBuildDir->text();
 }
 
 QStringList ProjectFileDialog::getIncludePaths() const
 {
-    return getPaths(mUI.mListIncludeDirs);
+    return getPaths(mUI->mListIncludeDirs);
 }
 
 QStringList ProjectFileDialog::getDefines() const
 {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-    return mUI.mEditDefines->text().trimmed().split(QRegExp("\\s*;\\s*"), Qt::SkipEmptyParts);
+    return mUI->mEditDefines->text().trimmed().split(QRegularExpression("\\s*;\\s*"), Qt::SkipEmptyParts);
 #else
-    return mUI.mEditDefines->text().trimmed().split(QRegExp("\\s*;\\s*"), QString::SkipEmptyParts);
+    return mUI->mEditDefines->text().trimmed().split(QRegularExpression("\\s*;\\s*"), QString::SkipEmptyParts);
 #endif
 }
 
 QStringList ProjectFileDialog::getUndefines() const
 {
-    const QString undefine = mUI.mEditUndefines->text().trimmed();
+    const QString undefine = mUI->mEditUndefines->text().trimmed();
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-    QStringList undefines = undefine.split(QRegExp("\\s*;\\s*"), Qt::SkipEmptyParts);
+    QStringList undefines = undefine.split(QRegularExpression("\\s*;\\s*"), Qt::SkipEmptyParts);
 #else
-    QStringList undefines = undefine.split(QRegExp("\\s*;\\s*"), QString::SkipEmptyParts);
+    QStringList undefines = undefine.split(QRegularExpression("\\s*;\\s*"), QString::SkipEmptyParts);
 #endif
     undefines.removeDuplicates();
     return undefines;
@@ -607,19 +614,19 @@ QStringList ProjectFileDialog::getUndefines() const
 
 QStringList ProjectFileDialog::getCheckPaths() const
 {
-    return getPaths(mUI.mListCheckPaths);
+    return getPaths(mUI->mListCheckPaths);
 }
 
 QStringList ProjectFileDialog::getExcludedPaths() const
 {
-    return getPaths(mUI.mListExcludedPaths);
+    return getPaths(mUI->mListExcludedPaths);
 }
 
 QStringList ProjectFileDialog::getLibraries() const
 {
     QStringList libraries;
-    for (int row = 0; row < mUI.mLibraries->count(); ++row) {
-        QListWidgetItem *item = mUI.mLibraries->item(row);
+    for (int row = 0; row < mUI->mLibraries->count(); ++row) {
+        QListWidgetItem *item = mUI->mLibraries->item(row);
         if (item->checkState() == Qt::Checked)
             libraries << item->text();
     }
@@ -628,54 +635,54 @@ QStringList ProjectFileDialog::getLibraries() const
 
 void ProjectFileDialog::setRootPath(const QString &root)
 {
-    mUI.mEditProjectRoot->setText(QDir::toNativeSeparators(root));
+    mUI->mEditProjectRoot->setText(QDir::toNativeSeparators(root));
 }
 
 void ProjectFileDialog::setBuildDir(const QString &buildDir)
 {
-    mUI.mEditBuildDir->setText(buildDir);
+    mUI->mEditBuildDir->setText(buildDir);
 }
 
 void ProjectFileDialog::setImportProject(const QString &importProject)
 {
-    mUI.mEditImportProject->setText(importProject);
+    mUI->mEditImportProject->setText(importProject);
 }
 
 void ProjectFileDialog::setIncludepaths(const QStringList &includes)
 {
-    foreach (QString dir, includes) {
+    for (const QString& dir : includes) {
         addIncludeDir(dir);
     }
 }
 
 void ProjectFileDialog::setDefines(const QStringList &defines)
 {
-    mUI.mEditDefines->setText(defines.join(";"));
+    mUI->mEditDefines->setText(defines.join(";"));
 }
 
 void ProjectFileDialog::setUndefines(const QStringList &undefines)
 {
-    mUI.mEditUndefines->setText(undefines.join(";"));
+    mUI->mEditUndefines->setText(undefines.join(";"));
 }
 
 void ProjectFileDialog::setCheckPaths(const QStringList &paths)
 {
-    foreach (QString path, paths) {
+    for (const QString& path : paths) {
         addCheckPath(path);
     }
 }
 
 void ProjectFileDialog::setExcludedPaths(const QStringList &paths)
 {
-    foreach (QString path, paths) {
+    for (const QString& path : paths) {
         addExcludePath(path);
     }
 }
 
 void ProjectFileDialog::setLibraries(const QStringList &libraries)
 {
-    for (int row = 0; row < mUI.mLibraries->count(); ++row) {
-        QListWidgetItem *item = mUI.mLibraries->item(row);
+    for (int row = 0; row < mUI->mLibraries->count(); ++row) {
+        QListWidgetItem *item = mUI->mLibraries->item(row);
         item->setCheckState(libraries.contains(item->text()) ? Qt::Checked : Qt::Unchecked);
     }
 }
@@ -709,18 +716,18 @@ void ProjectFileDialog::addSingleSuppression(const Suppressions::Suppression &su
         suppression_name = QString::fromStdString(suppression.getText());
     }
 
-    mUI.mListSuppressions->addItem(suppression_name);
+    mUI->mListSuppressions->addItem(suppression_name);
 }
 
 void ProjectFileDialog::setSuppressions(const QList<Suppressions::Suppression> &suppressions)
 {
-    mUI.mListSuppressions->clear();
+    mUI->mListSuppressions->clear();
     QList<Suppressions::Suppression> new_suppressions = suppressions;
     mSuppressions.clear();
-    foreach (const Suppressions::Suppression &suppression, new_suppressions) {
+    for (const Suppressions::Suppression &suppression : new_suppressions) {
         addSingleSuppression(suppression);
     }
-    mUI.mListSuppressions->sortItems();
+    mUI->mListSuppressions->sortItems();
 }
 
 void ProjectFileDialog::addCheckPath()
@@ -732,14 +739,14 @@ void ProjectFileDialog::addCheckPath()
 
 void ProjectFileDialog::editCheckPath()
 {
-    QListWidgetItem *item = mUI.mListCheckPaths->currentItem();
-    mUI.mListCheckPaths->editItem(item);
+    QListWidgetItem *item = mUI->mListCheckPaths->currentItem();
+    mUI->mListCheckPaths->editItem(item);
 }
 
 void ProjectFileDialog::removeCheckPath()
 {
-    const int row = mUI.mListCheckPaths->currentRow();
-    QListWidgetItem *item = mUI.mListCheckPaths->takeItem(row);
+    const int row = mUI->mListCheckPaths->currentRow();
+    QListWidgetItem *item = mUI->mListCheckPaths->takeItem(row);
     delete item;
 }
 
@@ -752,15 +759,15 @@ void ProjectFileDialog::addIncludeDir()
 
 void ProjectFileDialog::removeIncludeDir()
 {
-    const int row = mUI.mListIncludeDirs->currentRow();
-    QListWidgetItem *item = mUI.mListIncludeDirs->takeItem(row);
+    const int row = mUI->mListIncludeDirs->currentRow();
+    QListWidgetItem *item = mUI->mListIncludeDirs->takeItem(row);
     delete item;
 }
 
 void ProjectFileDialog::editIncludeDir()
 {
-    QListWidgetItem *item = mUI.mListIncludeDirs->currentItem();
-    mUI.mListIncludeDirs->editItem(item);
+    QListWidgetItem *item = mUI->mListIncludeDirs->currentItem();
+    mUI->mListIncludeDirs->editItem(item);
 }
 
 void ProjectFileDialog::addExcludePath()
@@ -780,34 +787,34 @@ void ProjectFileDialog::addExcludeFile()
 
 void ProjectFileDialog::editExcludePath()
 {
-    QListWidgetItem *item = mUI.mListExcludedPaths->currentItem();
-    mUI.mListExcludedPaths->editItem(item);
+    QListWidgetItem *item = mUI->mListExcludedPaths->currentItem();
+    mUI->mListExcludedPaths->editItem(item);
 }
 
 void ProjectFileDialog::removeExcludePath()
 {
-    const int row = mUI.mListExcludedPaths->currentRow();
-    QListWidgetItem *item = mUI.mListExcludedPaths->takeItem(row);
+    const int row = mUI->mListExcludedPaths->currentRow();
+    QListWidgetItem *item = mUI->mListExcludedPaths->takeItem(row);
     delete item;
 }
 
 void ProjectFileDialog::moveIncludePathUp()
 {
-    int row = mUI.mListIncludeDirs->currentRow();
-    QListWidgetItem *item = mUI.mListIncludeDirs->takeItem(row);
+    int row = mUI->mListIncludeDirs->currentRow();
+    QListWidgetItem *item = mUI->mListIncludeDirs->takeItem(row);
     row = row > 0 ? row - 1 : 0;
-    mUI.mListIncludeDirs->insertItem(row, item);
-    mUI.mListIncludeDirs->setCurrentItem(item);
+    mUI->mListIncludeDirs->insertItem(row, item);
+    mUI->mListIncludeDirs->setCurrentItem(item);
 }
 
 void ProjectFileDialog::moveIncludePathDown()
 {
-    int row = mUI.mListIncludeDirs->currentRow();
-    QListWidgetItem *item = mUI.mListIncludeDirs->takeItem(row);
-    const int count = mUI.mListIncludeDirs->count();
+    int row = mUI->mListIncludeDirs->currentRow();
+    QListWidgetItem *item = mUI->mListIncludeDirs->takeItem(row);
+    const int count = mUI->mListIncludeDirs->count();
     row = row < count ? row + 1 : count;
-    mUI.mListIncludeDirs->insertItem(row, item);
-    mUI.mListIncludeDirs->setCurrentItem(item);
+    mUI->mListIncludeDirs->insertItem(row, item);
+    mUI->mListIncludeDirs->setCurrentItem(item);
 }
 
 void ProjectFileDialog::addSuppression()
@@ -820,8 +827,8 @@ void ProjectFileDialog::addSuppression()
 
 void ProjectFileDialog::removeSuppression()
 {
-    const int row = mUI.mListSuppressions->currentRow();
-    QListWidgetItem *item = mUI.mListSuppressions->takeItem(row);
+    const int row = mUI->mListSuppressions->currentRow();
+    QListWidgetItem *item = mUI->mListSuppressions->takeItem(row);
     if (!item)
         return;
 
@@ -833,8 +840,8 @@ void ProjectFileDialog::removeSuppression()
 
 void ProjectFileDialog::editSuppression(const QModelIndex &)
 {
-    const int row = mUI.mListSuppressions->currentRow();
-    QListWidgetItem *item = mUI.mListSuppressions->item(row);
+    const int row = mUI->mListSuppressions->currentRow();
+    QListWidgetItem *item = mUI->mListSuppressions->item(row);
     int suppressionIndex = getSuppressionIndex(item->text());
     if (suppressionIndex >= 0) { // TODO what if suppression is not found?
         NewSuppressionDialog dlg;
@@ -864,11 +871,11 @@ void ProjectFileDialog::browseMisraFile()
                                                           tr("MISRA rule texts file (%1)").arg("*.txt"));
     if (!fileName.isEmpty()) {
         QSettings settings;
-        mUI.mEditMisraFile->setText(fileName);
+        mUI->mEditMisraFile->setText(fileName);
         settings.setValue(SETTINGS_MISRA_FILE, fileName);
 
-        mUI.mAddonMisra->setText("MISRA C 2012");
-        mUI.mAddonMisra->setEnabled(true);
-        updateAddonCheckBox(mUI.mAddonMisra, nullptr, getDataDir(), "misra");
+        mUI->mAddonMisra->setText("MISRA C 2012");
+        mUI->mAddonMisra->setEnabled(true);
+        updateAddonCheckBox(mUI->mAddonMisra, nullptr, getDataDir(), "misra");
     }
 }
